package bin4tsv ; 

our $VERSION = 0.01 ; 

package bin4tsv::ja ;
our $VERSION = 0.01 ;

=encoding utf8

=head1 NAME
 
bin4tsv

=head1 SYNOPSIS

=head1 DESCRIPTION
 
=head1 SEE ALSO

bin4tsv::ja
bin4tsv::en 


=cut


1 ; 
